==> blcr-0.2.0.tar.gz: blcr-0.2.0/cr_module/cr_ktrace.h <==
/*
 * Berkeley Lab Checkpoint/Restart (BLCR) for Linux is Copyright (c)
 * 2003, The Regents of the University of California, through Lawrence
 * Berkeley National Laboratory (subject to receipt of any required
 * approvals from the U.S. Dept. of Energy).  All rights reserved.
 *
 * Portions may be copyrighted by others, as may be noted in specific
 * copyright notices within specific files.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: cr_ktrace.h,v 1.2 2003/11/14 19:55:14 phargrov Exp $
 *
 *
 * Tracing output for checkpoint/restart kernel code.
 */
#ifndef _CR_KTRACE_H
#define _CR_KTRACE_H

#include <linux/sched.h>
#include "cr_module.h"

/* 
 * By default, regular messages (CR_INFO, CR_WARN, CR_ERR) are always on:
 * #define CR_QUIET to turn off.
 */

#ifdef CR_QUIET
# define CR_ERR(fmt, args...)
# define CR_WARN(fmt, args...)
# define CR_INFO(fmt, args...)
#else
# define CR_ERR(fmt, args...)	printk(KERN_ERR	    fmt "\n", ## args);
# define CR_WARN(fmt, args...)	printk(KERN_WARNING fmt "\n", ## args);
# define CR_INFO(fmt, args...)	printk(KERN_INFO    fmt "\n", ## args);
#endif

/* 
 * Tracing messages:  by default, turned off.  #define CR_USE_KTRACE to turn
 * on tracing, and set what types of tracing msgs to see by setting
 * cr_ktrace_mask (default is all tracing msgs).
 */

#if CR_KERNEL_TRACING
  /* for debugging ONLY: remove calls before checking in */
# define CR_KTRACE_DEBUG(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_DEBUG, args)
  /* for major high-level events ex: "phase 2 entered" */
# define CR_KTRACE_HIGH_LVL(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_HIGH_LVL, args)
  /* more detailed events ex: "woke up thread 4" */
# define CR_KTRACE_LOW_LVL(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_LOW_LVL, args)
  /* entering function */
# define CR_KTRACE_FUNC_ENTRY(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_FUNC_ENTRY, "entering " args)
  /* exiting function */
# define CR_KTRACE_FUNC_EXIT(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_FUNC_EXIT, "leaving " args)
  /* refcounting */
# define CR_KTRACE_REFCNT(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_REFCNT, args)
  /* resource (de)allocation */
# define CR_KTRACE_ALLOC(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_ALLOC, args)
  /* fixed limit reached */
# define CR_KTRACE_LIMIT(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_LIMIT, args)
  /* bad parameter recv'd */
# define CR_KTRACE_BADPARM(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_BADPARM, "EINVAL: " args)
  /* unusual case encountered: */
# define CR_KTRACE_UNEXPECTED(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_UNEXPECTED, args)

/* Tracing flags:
 *  - Flags that are normally on go in lowest 2 bytes, 
 *    and less commonly used ones in upper 2 bytes
 */
# define CR_KTRACETYPE_DEBUG		0x00000001 
# define CR_KTRACETYPE_HIGH_LVL		0x00000002 
# define CR_KTRACETYPE_LIMIT		0x00000004 
# define CR_KTRACETYPE_BADPARM		0x00000008
# define CR_KTRACETYPE_UNEXPECTED	0x00000010

# define CR_KTRACETYPE_LOW_LVL		0x00010000 
# define CR_KTRACETYPE_FUNC_ENTRY	0x00020000 
# define CR_KTRACETYPE_FUNC_EXIT	0x00040000 
# define CR_KTRACETYPE_REFCNT		0x00080000 
# define CR_KTRACETYPE_ALLOC		0x00100000 

/*  Common combinations, and default tracing setting */
# define CR_KTRACE_NONE	   0x00000000
# define CR_KTRACE_ALL	   0xFFFFFFFF
# define CR_KTRACE_FUNCS   (CR_KTRACETYPE_FUNC_ENTRY|CR_KTRACETYPE_FUNC_EXIT)
# define CR_KTRACE_USUAL_SUSPECTS 0x0000ffff
# define CR_KTRACE_DEFAULT CR_KTRACE_USUAL_SUSPECTS

# define CR_KTRACE(type, args...)                                            \
	 if (cr_ktrace_mask & (type)) {                                       \
		cr_print_trace(__FILE__, __LINE__, __FUNCTION__, ": " args); \
	 }
 extern unsigned int cr_ktrace_mask;
 extern void 
 cr_print_trace(const char *file, int line, const char *func, const char *fmt, ...)
		__attribute__((format (printf, 4, 5)));
#else
# define CR_KTRACE(args...)
# define CR_KTRACE_HIGH_LVL(args...)
# define CR_KTRACE_LOW_LVL(args...)
# define CR_KTRACE_FUNC_ENTRY(args...)
# define CR_KTRACE_FUNC_EXIT(args...)
# define CR_KTRACE_REFCNT(args...)
# define CR_KTRACE_ALLOC(args...)
# define CR_KTRACE_LIMIT(args...)
# define CR_KTRACE_BADPARM(args...)
# define CR_KTRACE_UNEXPECTED(args...)
#endif  /* CR_KERNEL_TRACING */

#endif  /* _CR_KTRACE_H */

==> blcr-0.6.2.tar.gz: blcr-0.6.2/cr_module/cr_ktrace.h <==
/*
 * Berkeley Lab Checkpoint/Restart (BLCR) for Linux is Copyright (c)
 * 2003, The Regents of the University of California, through Lawrence
 * Berkeley National Laboratory (subject to receipt of any required
 * approvals from the U.S. Dept. of Energy).  All rights reserved.
 *
 * Portions may be copyrighted by others, as may be noted in specific
 * copyright notices within specific files.
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * $Id: cr_ktrace.h,v 1.5 2007/01/26 21:18:36 phargrov Exp $
 *
 *
 * Tracing output for checkpoint/restart kernel code.
 */
#ifndef _CR_KTRACE_H
#define _CR_KTRACE_H

#include "cr_module.h"

/* 
 * By default, regular messages (CR_INFO, CR_WARN, CR_ERR) are always on:
 * #define CR_QUIET to turn off.
 */

#ifdef CR_QUIET
# define CR_ERR(fmt, args...)
# define CR_WARN(fmt, args...)
# define CR_INFO(fmt, args...)
#else
# define CR_ERR(fmt, args...)	printk(KERN_ERR	    fmt "\n", ## args)
# define CR_WARN(fmt, args...)	printk(KERN_WARNING fmt "\n", ## args)
# define CR_INFO(fmt, args...)	printk(KERN_INFO    fmt "\n", ## args)
#endif

/* 
 * Tracing messages:  by default, turned off.  #define CR_USE_KTRACE to turn
 * on tracing, and set what types of tracing msgs to see by setting
 * cr_ktrace_mask (default is all tracing msgs).
 */

#if CR_KERNEL_TRACING
  /* for debugging ONLY: remove calls before checking in */
# define CR_KTRACE_MARK()		printk(KERN_ERR	    "@ %s:%d\n", __FILE__, __LINE__)
# define CR_KTRACE_DEBUG(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_DEBUG, args)
  /* for major high-level events ex: "phase 2 entered" */
# define CR_KTRACE_HIGH_LVL(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_HIGH_LVL, args)
  /* more detailed events ex: "woke up thread 4" */
# define CR_KTRACE_LOW_LVL(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_LOW_LVL, args)
  /* entering function */
# define CR_KTRACE_FUNC_ENTRY(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_FUNC_ENTRY, "entering " args)
  /* exiting function */
# define CR_KTRACE_FUNC_EXIT(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_FUNC_EXIT, "leaving " args)
  /* refcounting */
# define CR_KTRACE_REFCNT(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_REFCNT, args)
  /* resource (de)allocation */
# define CR_KTRACE_ALLOC(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_ALLOC, args)
  /* fixed limit reached */
# define CR_KTRACE_LIMIT(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_LIMIT, args)
  /* bad parameter recv'd */
# define CR_KTRACE_BADPARM(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_BADPARM, "EINVAL: " args)
  /* unusual case encountered: */
# define CR_KTRACE_UNEXPECTED(args...)	\
	 CR_KTRACE(CR_KTRACETYPE_UNEXPECTED, args)

/* Tracing flags:
 *  - Flags that are normally on go in lowest 2 bytes, 
 *    and less commonly used ones in upper 2 bytes
 */
# define CR_KTRACETYPE_DEBUG		0x00000001 
# define CR_KTRACETYPE_HIGH_LVL		0x00000002 
# define CR_KTRACETYPE_LIMIT		0x00000004 
# define CR_KTRACETYPE_BADPARM		0x00000008
# define CR_KTRACETYPE_UNEXPECTED	0x00000010

# define CR_KTRACETYPE_LOW_LVL		0x00010000 
# define CR_KTRACETYPE_FUNC_ENTRY	0x00020000 
# define CR_KTRACETYPE_FUNC_EXIT	0x00040000 
# define CR_KTRACETYPE_REFCNT		0x00080000 
# define CR_KTRACETYPE_ALLOC		0x00100000 

/*  Common combinations, and default tracing setting */
# define CR_KTRACE_NONE	   0x00000000
# define CR_KTRACE_ALL	   0xFFFFFFFF
# define CR_KTRACE_FUNCS   (CR_KTRACETYPE_FUNC_ENTRY|CR_KTRACETYPE_FUNC_EXIT)
# define CR_KTRACE_USUAL_SUSPECTS 0x0000ffff
# define CR_KTRACE_DEFAULT CR_KTRACE_USUAL_SUSPECTS

# define CR_KTRACE(type, args...)                                            \
	 if (cr_ktrace_mask & (type)) {                                       \
		cr_print_trace(__FILE__, __LINE__, __FUNCTION__, ": " args); \
	 }
 extern unsigned int cr_ktrace_mask;
 extern void 
 cr_print_trace(const char *file, int line, const char *func, const char *fmt, ...)
		__attribute__((format (printf, 4, 5)));
#else
# define CR_KTRACE_MARK()
# define CR_KTRACE(args...)
# define CR_KTRACE_HIGH_LVL(args...)
# define CR_KTRACE_LOW_LVL(args...)
# define CR_KTRACE_FUNC_ENTRY(args...)
# define CR_KTRACE_FUNC_EXIT(args...)
# define CR_KTRACE_REFCNT(args...)
# define CR_KTRACE_ALLOC(args...)
# define CR_KTRACE_LIMIT(args...)
# define CR_KTRACE_BADPARM(args...)
# define CR_KTRACE_UNEXPECTED(args...)
#endif  /* CR_KERNEL_TRACING */

#endif  /* _CR_KTRACE_H */
